==> gallery_assist_comments-6.x-1.0.tar.gz: gallery_assist_comments/js/gallery_assist_comments.js <==
/* $Id: gallery_assist_comments.js,v 1.1 2010/05/18 21:37:13 quiptime Exp $ */

Drupal.behaviors.GacFunctions = function (context) {
 if (Drupal.settings.gacLinkCA == 2 || Drupal.settings.gacLinkCB == 2) { setToggleColor(); collapse('hide'); ToggleFunc(); }
 if (Drupal.settings.gacLinkCA == 3 || Drupal.settings.gacLinkCB == 3) { setToggleColor(); collapse('show'); ToggleFunc(); }
 if (Drupal.settings.gacLinkCA == 1 || Drupal.settings.gacLinkCB == 1) { $('#ga-comment-area-form-above').show(); $('#ga-comment-area-form-below').show(); }
 if (Drupal.settings.gacCCA || Drupal.settings.gacCCB) { $("#edit-comment-body").counter({ count: Drupal.settings.gacCountA, goal: Drupal.settings.gacGoalA }); $("#edit-comment-body-1").counter({ count: Drupal.settings.gacCountB, goal: Drupal.settings.gacGoalB }); }
 function collapse (arg) { if (arg == 'show') { $('#ga-comment-area-form-above').show(); $('#ga-comment-area-form-below').show(); } if (arg == 'hide') { $('#ga-comment-area-form-above').hide(); $('#ga-comment-area-form-below').hide(); } }
 function setToggleColor () { var aColor = $('.get-link-color a').css('color'); $('#ga-comment-form-toggle-above').css({color: aColor}); $('#ga-comment-form-toggle-below').css({color: aColor}); $('#ga-comment-form-toggle-above').addClass('toggle-pointer'); $('#ga-comment-form-toggle-below').addClass('toggle-pointer'); }
 function ToggleFunc () { $('#ga-comment-form-toggle-above').click(function() { $('#ga-comment-area-form-above').toggle(); }); $('#ga-comment-form-toggle-below').click(function() { $('#ga-comment-area-form-below').toggle(); }); }
}

==> gallery_assist_comments-6.x-1.1.tar.gz: gallery_assist_comments/js/gallery_assist_comments.js <==
/* $Id: gallery_assist_comments.js,v 1.1.2.3 2010/05/19 19:40:48 quiptime Exp $ */

Drupal.behaviors.GacFunctions = function (context) {
 if (Drupal.settings.gacLinkCA == 2 || Drupal.settings.gacLinkCB == 2) { setToggleColor(); collapse('hide'); ToggleFunc(); }
 if (Drupal.settings.gacLinkCA == 3 || Drupal.settings.gacLinkCB == 3) { setToggleColor(); collapse('show'); ToggleFunc(); }
 if (Drupal.settings.gacLinkCA == 1 || Drupal.settings.gacLinkCB == 1) { $('#ga-comment-area-form-above').show(); $('#ga-comment-area-form-below').show(); }
 if (Drupal.settings.gacCCA && Drupal.settings.gacCCB) { $("#edit-comment-body").counter({ count: Drupal.settings.gacCountA, goal: Drupal.settings.gacGoalA }); $("#edit-comment-body-1").counter({ count: Drupal.settings.gacCountB, goal: Drupal.settings.gacGoalB }); }
 if (Drupal.settings.gacCCA && !Drupal.settings.gacCCB) { $("#edit-comment-body").counter({ count: Drupal.settings.gacCountA, goal: Drupal.settings.gacGoalA }); }
 if (!Drupal.settings.gacCCA && Drupal.settings.gacCCB) { $("#edit-comment-body").counter({ count: Drupal.settings.gacCountB, goal: Drupal.settings.gacGoalB }); }
 function collapse (arg) { if (arg == 'show') { $('#ga-comment-area-form-above').show(); $('#ga-comment-area-form-below').show(); } if (arg == 'hide') { $('#ga-comment-area-form-above').hide(); $('#ga-comment-area-form-below').hide(); } }
 function setToggleColor () { var aColor = $('.get-link-color a').css('color'); $('#ga-comment-form-toggle-above').css({color: aColor}); $('#ga-comment-form-toggle-below').css({color: aColor}); $('#ga-comment-form-toggle-above').addClass('toggle-pointer'); $('#ga-comment-form-toggle-below').addClass('toggle-pointer'); }
 function ToggleFunc () { $('#ga-comment-form-toggle-above').click(function() { $('#ga-comment-area-form-above').toggle(); }); $('#ga-comment-form-toggle-below').click(function() { $('#ga-comment-area-form-below').toggle(); }); }
}
